@@ -85,7 +85,7 @@ CMD = "ml"  # The command line tool.
 EXT_MLM = ".mlm"  # Archive filename extension
 EXT_AIPK = ".aipk"  # Backward compatibility
 
-VERSION = "3.9.10"  # DO NOT MODIFY. Managed from ../Makefile.
+VERSION = "3.10.2"  # DO NOT MODIFY. Managed from ../Makefile.
 
 OPTIONS = {
     # Global command line options
@@ -170,17 +170,19 @@ COMMANDS = {
         "func": "remove_mlm",
     },
     "install": {
-        "description": "install a named model, local model file or URL",
+        "description": "Install a named model, local model file or URL",
         "argument": {
             "model": {},
-            "-i": {"help": "SSH key path"},
+            "-i": {"help": "Path to SSH key."},
             "--yes": {
                 "action": "store_true",
-                "help": 'assume "yes" as answer to all prompts',
+                "help": 'Assume "yes" as answer to all prompts',
             },
-            "-y": {"action": "store_true", "help": 'the same as "--yes"'},
+            "-y": {"action": "store_true"},
+            # 20220107 Not yet - is it really needed? Use RENAME.
+            # "--name": {"help": "Local name of model."},
         },
-        "usage": "  install    <model>   install a named model, local model file or URL",
+        "usage": "  Install    <model>   Install a named model, local model file or URL.",
         "func": "install_model",
         "next": ["configure"],
     },
@@ -226,6 +228,19 @@ COMMANDS = {
         "func": "configure_model",
         "next": ["readme"],
     },
+    "rename": {
+        "description": "rename a model",
+        "argument": {
+            "old": {},
+            "new": {},
+            "--force": {
+                "action": "store_true",
+                "help": "don't check if old alreadsy exists",
+            }
+        },
+        "usage": "  rename <old> <new>  rename an installed model",
+        "func": "rename_model",
+    },
     "uninstall": {
         "description": "uninstall a model or all models",
         "argument": {
